@@ -6,9 +6,13 @@ use strict;
 use warnings;
 
 use Carp;
-use Exporter qw{ import };
+use Exporter;
 
-our $VERSION = '0.005';
+# Beause the Perl 5.6 Exporter does not export import().
+BEGIN {
+    *import	= \&Exporter::import;
+}
+our $VERSION = '0.007';
 
 our @EXPORT_OK = qw{ __any };
 
@@ -152,7 +156,7 @@ Tom Wyant (wyant at cpan dot org)
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2016 by Thomas R. Wyant, III
+Copyright (C) 2016-2019 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
